@@ -4,6 +4,7 @@ import (
 	"context"
 	"strings"
 
+	"github.com/sachaos/todoist/lib"
 	"github.com/urfave/cli/v2"
 )
 
@@ -34,7 +35,7 @@ func Modify(c *cli.Context) error {
 		return names
 	}(c.String("label-names"))
 
-	item.DateString = c.String("date")
+	item.Due = &todoist.Due{String: c.String("date")}
 
 	projectID := c.String("project-id")
 	if projectID == "" {
